Overview
========


Pyramid configuration with OpenTaobao-API integration.

Configuration
----------------

::
   
    pyramid.includes = pyramid_taobao
    taobao.app_id = xxxxxxxxxxx
    taobao.sercet_code = xxxxxxxxxxx

